fn break_crypto(conn: &Smb2Conn, signed: bool) -> BreakCryptoExpand description
Snapshot the crypto material needed to protect an oplock break sent later to this holder.
fn break_crypto(conn: &Smb2Conn, signed: bool) -> BreakCryptoSnapshot the crypto material needed to protect an oplock break sent later to this holder.