break_dir_lease

Function break_dir_lease 

pub(crate) fn break_dir_lease(
    server: &Arc<ServerShared>,
    conn: &Smb2Conn,
    dir: &str,
    owner: [u8; 16],
    clear: u32,
)
Revoke caching bits (clear) on a directory lease held on dir when its contents or state change, unless the change originates from the lease holder itself ([MS-SMB2] 3.3.1.4). owner is the file id of the open performing the change, used to suppress a self-break.