break_subtree_lease_wait

Function break_subtree_lease_wait 

pub(crate) async fn break_subtree_lease_wait(
    server: &Arc<ServerShared>,
    conn: &Smb2Conn,
    dir: &str,
    owner: [u8; 16],
    clear: u32,
)
Break HANDLE caching on every directory lease across the subtree rooted at dir and wait (briefly) for each holder to acknowledge, as required before a directory rename that invalidates the subtree’s cached handles may be evaluated ([MS-SMB2] 3.3.1.4). owner is the renaming open, suppressed from the break.